@@ -13,7 +13,7 @@ if on_rtd:
     os.environ["HOME"] = "/home/docs/"
     os.environ["LANG"] = "C"
     os.environ["LC_ALL"] = "C"
-    os.environ["HIDE_PARFIVE_PROGESS"] = "True"
+    os.environ["PARFIVE_HIDE_PROGRESS"] = "True"
 
 # -- Non stdlib imports --------------------------------------------------------
 from sunkit_instruments import __version__  # NOQA
