@@ -5,19 +5,16 @@ Sunkit-instruments
 A SunPy-affiliated package for solar instrument-specific tools.
 
 * Homepage: https://sunpy.org
-* Documentation: https://sunkit-instruments.readthedocs.io/en/latest/
+* Documentation: https://docs.sunpy.org/projects/sunkit-instruments/en/latest/
+* Source code: https://github.com/sunpy/sunkit-instruments
 """
 import sys
 
+from .version import version as __version__  # NOQA
+
 # Enforce Python version check during package import.
 __minimum_python_version__ = "3.7"
 
-try:
-    from .version import __version__
-except ImportError:
-    print("version.py not found, please reinstall sunkit_instruments.")
-    __version__ = "unknown"
-
 
 class UnsupportedPythonError(Exception):
     """
@@ -25,9 +22,12 @@ class UnsupportedPythonError(Exception):
     """
 
 
-if sys.version_info < tuple(int(val) for val in __minimum_python_version__.split('.')):
+if sys.version_info < tuple(int(val) for val in __minimum_python_version__.split(".")):
     # This has to be .format to keep backwards compatibly.
     raise UnsupportedPythonError(
-        "sunkit_instruments does not support Python < {}".format(__minimum_python_version__))
+        "sunkit_instruments does not support Python < {}".format(
+            __minimum_python_version__
+        )
+    )
 
-__all__ = []
+__all__ = ["__version__"]
